SessionState

Enum SessionState 

pub enum SessionState {
    Disconnected,
    SyncConnected,
    AuthFailed,
    ConnectedReadOnly,
    Expired,
    Closed,
}
ZooKeeper session states.

Variants



Disconnected

Intermediate state states that client is disconnected from zookeeper cluster.

In case of all clients dropped, this state is not reported. This differs from Java client which is indeterminate currently. See ZOOKEEPER-4702.



SyncConnected

Intermediate state states that client has recovered from disconnected state.



AuthFailed

Terminal state states that client failed in authentication.



ConnectedReadOnly

Intermediate state states that client is connected to a readonly server.



Expired

Terminal state states that zookeeper session is expired.



Closed

Terminal state states that zookeeper client has been closed.

Implementations