pub struct SaslOptions(/* private fields */);Available on crate features
sasl-digest-md5 or sasl-gssapi or sasl only.Expand description
Client side SASL options.
Implementations
Sourceimpl SaslOptions
impl SaslOptions
Sourcepub fn gssapi() -> GssapiSaslOptions
Available on crate features sasl-gssapi or sasl only.
pub fn gssapi() -> GssapiSaslOptions
sasl-gssapi or sasl only.Constructs a default GssapiSaslOptions for further customization.
Make sure localhost is granted by Kerberos KDC, unlike Java counterpart this library provides no mean to grant ticket from KDC but simply utilizes whatever the ticket cache have.
Sourcepub fn digest_md5(
username: impl Into<Cow<'static, str>>,
password: impl Into<Cow<'static, str>>,
) -> DigestMd5SaslOptions
Available on crate features sasl-digest-md5 or sasl only.
pub fn digest_md5( username: impl Into<Cow<'static, str>>, password: impl Into<Cow<'static, str>>, ) -> DigestMd5SaslOptions
sasl-digest-md5 or sasl only.Construct a DigestMd5SaslOptions for further customization.