Stat

Struct Stat 

pub struct Stat {
    pub czxid: i64,
    pub mzxid: i64,
    pub pzxid: i64,
    pub ctime: i64,
    pub mtime: i64,
    pub version: i32,
    pub cversion: i32,
    pub aversion: i32,
    pub ephemeral_owner: i64,
    pub data_length: i32,
    pub num_children: i32,
}
ZooKeeper node stat.

Fields

czxid: i64

The zxid of the change that caused this znode to be created.

mzxid: i64

The zxid of the change that last modified this znode.

pzxid: i64

The zxid of the change that last modified children of this znode.

ctime: i64

The time in milliseconds from epoch when this znode was created.

mtime: i64

The time in milliseconds from epoch when this znode was last modified.

version: i32

The number of changes to the data of this znode.

cversion: i32

The number of changes to the children of this znode.

aversion: i32

The number of changes to the ACL of this znode.

ephemeral_owner: i64

The session id of the owner of this znode if the znode is an ephemeral node. If it is not an ephemeral node, it will be zero.

data_length: i32

The length of the data field of this znode.

num_children: i32

The number of children of this znode.

Implementations

Source

impl Stat

pub fn is_invalid(&self) -> bool

Tests whether this stat is invalid.

This method is exported to circumvent bugs in ZooKeeper server. See ZOOKEEPER-4026 and ZOOKEEPER-4667 for reference.